#!/usr/bin/env node

const fs = require('fs');
const path = require('path');

// Check if correct number of arguments are provided
if (process.argv.length !== 4) {
  console.error('Usage: npx create-file-structure <path-to-structure-file> <base-directory>');
  process.exit(1);
}

const structureFilePath = process.argv[2];
const baseDir = process.argv[3];

// Read and parse the structure file
let structure;
try {
  structure = require(path.resolve(structureFilePath));
} catch (error) {
  console.error(`Error reading structure file: ${error.message}`);
  process.exit(1);
}

// Function to create the file structure recursively
function createStructure(item, currentPath) {
  const itemPath = path.join(currentPath, item.name);

  try {
    if (item.type === 'directory') {
      fs.mkdirSync(itemPath, { recursive: true });
      console.log(`Created directory: ${itemPath}`);

      if (item.children) {
        item.children.forEach(child => createStructure(child, itemPath));
      }
    } else if (item.type === 'file') {
      fs.writeFileSync(itemPath, item.content || '');
      console.log(`Created file: ${itemPath}`);
    }
  } catch (error) {
    console.warn(`Failed to create item at ${itemPath}: ${error.message}`);
  }
}

// Create base directory if it doesn't exist
if (!fs.existsSync(baseDir)) {
  try {
    fs.mkdirSync(baseDir, { recursive: true });
    console.log(`Created base directory: ${baseDir}`);
  } catch (error) {
    console.error(`Error creating base directory: ${error.message}`);
    process.exit(1);
  }
}

// Start creating the structure
createStructure(structure, baseDir);

console.log('File structure creation completed.');
